@@ -199,20 +199,20 @@ This is only raised within the "Process"-function.
             
             # Prefix (=Name) must be a string and not empty
             if type(wPrefix) != str:
-                raise self.DeclarationError(f"Name of child '{wPrefix} is not a string")
+                raise self.DeclarationError(f"{self.FullPrefix}: Name of child '{wPrefix} is not a string")
             wPrefix = wPrefix.strip()
             if wPrefix == '':
-                raise self.DeclarationError(f"Name of child could not be blank")
+                raise self.DeclarationError(f"{self.FullPrefix}: Name of child could not be blank")
             
             # the declaration of a child has to bee a dictionary
             if type(wDict) != dict:
-                raise self.DeclarationError(f"Child definition for '{wPrefix} is not a dictionary")
+                raise self.DeclarationError(f"{self.FullPrefix}: Child definition for '{wPrefix} is not a dictionary")
             
             # the declaration of a child needs at least a 'Def' entry whitch is a dictionary
             if 'Def' not in wDict:
-                raise self.DeclarationError(f"Child definition for '{wPrefix} does not include 'Def'")
+                raise self.DeclarationError(f"{self.FullPrefix}: Child definition for '{wPrefix} does not include 'Def'")
             if type(wDict['Def']) != dict:
-                raise self.DeclarationError(f"'Def' in child definition for '{wPrefix} is not a dictionary")
+                raise self.DeclarationError(f"{self.FullPrefix}: 'Def' in child definition for '{wPrefix} is not a dictionary")
             
             # if 'Children' not given set it to an empty dictionary
             if 'Children' not in wDict:
@@ -222,7 +222,7 @@ This is only raised within the "Process"-function.
                 
             # the declaration of "Children" has to bee a dictionary
             if type(wDict['Children']) != dict:
-                raise self.DeclarationError(f"'Children' in child definition for '{wPrefix} is not a dictionary")
+                raise self.DeclarationError(f"{self.FullPrefix}: 'Children' in child definition for '{wPrefix} is not a dictionary")
             
             # if 'Desc' not given set it to ''
             if 'Desc' not in wDict:
@@ -230,7 +230,7 @@ This is only raised within the "Process"-function.
                 
             # the declaration of "Desc" has to bee a string
             if type(wDict['Desc']) != str:
-                raise self.DeclarationError(f"'Desc' in child definition for '{wPrefix} is not a string")
+                raise self.DeclarationError(f"{self.FullPrefix}: 'Desc' in child definition for '{wPrefix} is not a string")
             
             # if 'AddPar' not given set it to ''
             if 'AddPar' not in wDict:
@@ -238,7 +238,7 @@ This is only raised within the "Process"-function.
             
             # the declaration of "AddPar" has to bee a string
             if type(wDict['AddPar']) != str:
-                raise self.DeclarationError(f"'AddPar' in child definition for '{wPrefix} is not a string")
+                raise self.DeclarationError(f"{self.FullPrefix}: 'AddPar' in child definition for '{wPrefix} is not a string")
             
             # now add all the children (if necessary also recursive)
             self.AddChild(Prefix = wPrefix, 
@@ -394,10 +394,8 @@ This is only raised within the "Process"-function.
         else:
             try:
                 p = dict(self.__Parent.items())
-#                p = list(self.__Parent.items())
             except:
                 p = {}
-#                p = []
             r = {}
             for key,value in p.items():
                 r[key] = value
@@ -406,8 +404,6 @@ This is only raised within the "Process"-function.
             Res = []
             for key,value in r.items():
                 Res.append( (key, value))
-            # Res = list({ **p , **dict(self.__WorkDict.items())})
-#            Res = p + list(self.__WorkDict.items())
         try:
             Res.sort()
         except:
@@ -442,12 +438,12 @@ This is only raised within the "Process"-function.
             self.DeclarationError: If a parameter is invalid
         """        
         if type(Prefix) != str:
-            raise self.DeclarationError(f"Prefix is not a string")
+            raise self.DeclarationError(f"{self.FullPrefix}: Prefix is not a string")
         p = Prefix.lower().strip()
         if p in self.__Children:
-            raise self.DeclarationError(f"Prefix '{p}' is already used")
+            raise self.DeclarationError(f"{self.FullPrefix}: Prefix '{p}' is already used")
         if p == GLOBAL_NAME:
-            raise self.DeclarationError(f"Prefix '{p}' is {GLOBAL_NAME} -> invalid!")
+            raise self.DeclarationError(f"{self.FullPrefix}: Prefix '{p}' is {GLOBAL_NAME} -> invalid!")
         self.__Children[p] = self.__class__( Def = Def,
                                     Args = self.__Argumente,
                                     Translate = self.__DoTranslate,
@@ -581,7 +577,7 @@ Def-dict: a dictionary of dictionaries
         if type(Def) == dict:
             self.__Definition = Def
         else:
-            raise TypeError('Def is not a dict')
+            raise TypeError(f"{self.FullPrefix}: Def is not a dict")
         self.__IsPrepared = False   # we need a Prepare-call after this 
 
     @property
@@ -593,6 +589,33 @@ Def-dict: a dictionary of dictionaries
         """        
         return copy.deepcopy(self.__Definition)
 
+    @property
+    def FullPrefix(self) -> str:
+        """Returns the full qualified prefix of this instance
+        e.g.: global.alpha.gamma
+        if alpha is a child of global and gamma (this instance) is a child of alpha
+        """        
+        Erg = self.Parents
+        if Erg != '':
+            Erg += '.'
+        return Erg + self.__Prefix
+    
+
+    @property
+    def Parents(self) -> str:
+        """Returns the full qualified parents of this instance
+        e.g.: global.alpha
+        if alpha is a child of global and gamma (this instance) is a child of alpha
+        """        
+        Erg = ''
+        if self.__Parent is None:
+            return ''
+        Erg = self.__Parent.Parents
+        if Erg != '':
+            Erg += '.'
+        Erg += self.__Parent.__Prefix
+        return Erg
+    
     def GetCmdPar(self, Entry: str, dotted: bool = False, parents: bool = False) -> str:
         """Return the commandline-options for one entry
 
@@ -670,31 +693,31 @@ Def-dict: a dictionary of dictionaries
         """
         if UserPars is not None:
             if type(UserPars) != dict:
-                raise TypeError('UserPars is not a dict')
+                raise TypeError(f'{self.FullPrefix}: UserPars is not a dict')
             for k in UserPars.keys():
                 if not k in self.__WorkPars:
-                    raise self.DeclarationError(f"UserPars {k} is invalid. Valid values are {self.__WorkPars.keys()}")
+                    raise self.DeclarationError(f"{self.FullPrefix}: UserPars {k} is invalid. Valid values are {self.__WorkPars.keys()}")
                 v = UserPars[k]
                 if type(v) != str:
-                    raise TypeError(f"Value of UserPars {k} is not a string")
+                    raise TypeError(f"{self.FullPrefix}: Value of UserPars {k} is not a string")
                 self.__WorkPars[k] = v
             Double = self.__CheckMulti(self.__WorkPars)
             if Double:
-                raise self.DeclarationError(f"UserPars {Double} have the same value {self.__WorkPars[Double[0]]}")
+                raise self.DeclarationError(f"{self.FullPrefix}: UserPars {Double} have the same value {self.__WorkPars[Double[0]]}")
 
         if UserModes is not None:
             if type(UserModes) != dict:
-                raise TypeError('UserModes is not a dict')
+                raise TypeError(f'{self.FullPrefix}: UserModes is not a dict')
             for k in UserModes.keys():
                 if not k in self.__WorkModes:
-                    raise self.DeclarationError(f"UserModes {k} is invalid. Valid values are {self.__WorkModes.keys()}")
+                    raise self.DeclarationError(f"{self.FullPrefix}: UserModes {k} is invalid. Valid values are {self.__WorkModes.keys()}")
                 v = UserModes[k]
                 if type(v) != str:
-                    raise TypeError(f"Value of UserModes {k} is not a string")
+                    raise TypeError(f"{self.FullPrefix}: Value of UserModes {k} is not a string")
                 self.__WorkModes[k] = v
             Double = self.__CheckMulti(self.__WorkModes)
             if Double:
-                raise self.DeclarationError(f"UserModes {Double} have the same value {self.__WorkModes[Double[0]]}")
+                raise self.DeclarationError(f"{self.FullPrefix}: UserModes {Double} have the same value {self.__WorkModes[Double[0]]}")
 
 
     def __CheckMulti(self, Dict: dict) -> list:
@@ -717,7 +740,7 @@ Def-dict: a dictionary of dictionaries
         elif type(Args) == list or type(Args) == tuple:
             self.__Argumente = Args
         else:
-            raise TypeError('Args is not a list or tuple')
+            raise TypeError(f'{self.FullPrefix}: Args is not a list or tuple')
         for c in self.__Children.values():
             c.SetArgs(Args)
 
@@ -738,10 +761,10 @@ Def-dict: a dictionary of dictionaries
             if isinstance(Chk, types.FunctionType):
                 a = inspect.getfullargspec(Chk).args
                 if len(a) != 2:
-                    raise TypeError('Check function does not take 2 arguments')
+                    raise TypeError(f'{self.FullPrefix}: Check function does not take 2 arguments')
                 self.__ChkFunc = Chk
             else:
-                raise TypeError('Check is not a function')
+                raise TypeError(f'{self.FullPrefix}: Check is not a function')
         self.__IsPrepared = False   # we need a Prepare-call after this
         for c in self.__Children.values():
             c.SetChk(Chk)
@@ -761,7 +784,7 @@ Def-dict: a dictionary of dictionaries
         if type(Desc) == str:
             self.__Description = Desc
         else:
-            raise TypeError('Desc is not a string')
+            raise TypeError(f'{self.FullPrefix}: Desc is not a string')
         self.__IsPrepared = False   # we need a Prepare-call after this
 
     def SetAddPar(self, AddPar: str = "") -> None:
@@ -778,7 +801,7 @@ Def-dict: a dictionary of dictionaries
         if type(AddPar) == str:
             self.__AddPar = AddPar
         else:
-            raise TypeError('AddPar is not a string')
+            raise TypeError(f'{self.FullPrefix}: AddPar is not a string')
         self.__IsPrepared = False   # we need a Prepare-call after this
 
     def MyProgName(self) -> str:
@@ -939,7 +962,7 @@ Def-dict: a dictionary of dictionaries
             if self.__WorkPars['mode'] in ParKeys:
                 ParMode = SingleDef[self.__WorkPars['mode']]
             else:
-                raise self.DeclarationError(f"No mode setting in Def for {ParName}")
+                raise self.DeclarationError(f"{self.FullPrefix}: No mode setting in Def for {ParName}")
             if ParMode == self.__WorkModes['path']:
                 Ut_Type = 'path'
                 SingleDef[self.__WorkPars['needoption']] = True
@@ -1049,10 +1072,10 @@ Def-dict: a dictionary of dictionaries
                 if type(wText) == list or type(wText) == tuple:
                     for ws in wText:
                         if not type(ws) == str:
-                            raise self.DeclarationError(f"One of the long values for {ParName} is not a string")
+                            raise self.DeclarationError(f"{self.FullPrefix}: One of the long values for {ParName} is not a string")
                         l = len(ws)
                         if ('--' + ws) in self.__ParDict.keys():
-                            raise self.DeclarationError(f"Double long value for {ParName}: {ws}")
+                            raise self.DeclarationError(f"{self.FullPrefix}: Double long value for {ParName}: {ws}")
                         self.__ParDict['--' + ws] = ParName
                         for ListPar in self.__ModeToList:
                             if ParMode == ListPar:
@@ -1066,10 +1089,10 @@ Def-dict: a dictionary of dictionaries
                         if l > LongParLen:
                             LongParLen = l
                 elif not type(wText) == str:
-                    raise self.DeclarationError(f"Long value for {ParName} is not a string")
+                    raise self.DeclarationError(f"{self.FullPrefix}: Long value for {ParName} is not a string")
                 else:
                     if ('--' + wText) in self.__ParDict.keys():
-                        raise self.DeclarationError(f"Double long value for {ParName}: {wText}")
+                        raise self.DeclarationError(f"{self.FullPrefix}: Double long value for {ParName}: {wText}")
                     self.__ParDict['--' + wText] = ParName
                     for ListPar in self.__ModeToList:
                         if ParMode == ListPar:
@@ -1087,10 +1110,10 @@ Def-dict: a dictionary of dictionaries
                 if type(wText) == list or type(wText) == tuple:
                     for ws in wText:
                         if not type(ws) == str:
-                            raise self.DeclarationError(f"One of the short values for {ParName} is not a string")
+                            raise self.DeclarationError(f"{self.FullPrefix}: One of the short values for {ParName} is not a string")
                         for c in ws:
                             if ('-' + c) in self.__ParDict.keys():
-                                raise self.DeclarationError(f"Double short value for {ParName}: {c}")
+                                raise self.DeclarationError(f"{self.FullPrefix}: Double short value for {ParName}: {c}")
                             self.__ParDict['-' + c] = ParName
                             for ListPar in self.__ModeToList:
                                 if ParMode == ListPar:
@@ -1101,11 +1124,11 @@ Def-dict: a dictionary of dictionaries
                             if NeedOpt:
                                 self.__ShortList += ":"
                 elif not type(wText) == str:
-                    raise self.DeclarationError(f"Short value for {ParName} is not a string")
+                    raise self.DeclarationError(f"{self.FullPrefix}: Short value for {ParName} is not a string")
                 else:
                     for c in wText:
                         if ('-' + c) in self.__ParDict.keys():
-                            raise self.DeclarationError(f"Double short value for {ParName}: {c}")
+                            raise self.DeclarationError(f"{self.FullPrefix}: Double short value for {ParName}: {c}")
                         self.__ParDict['-' + c] = ParName
                         for ListPar in self.__ModeToList:
                             if ParMode == ListPar:
@@ -2249,6 +2272,10 @@ Konsole und nicht auf syslog""",
             return
         if Erg:
             return
+        g =m.Child['alpha'].Child['gamma'] 
+        print(g.Parents)
+        print(g.FullPrefix)
+        
         # m['TopLevel'] = 'Top'
         # m.Child['alpha']['AlphaLevel'] = 'Alpha'
         # m.Child['alpha'].Child['gamma']['GammaLevel'] = 'Gamma'
